Package: RforProteomics
Type: Package
Title: Companion package to the 'Using R and Bioconductor for
        proteomics data analysis' publication
Version: 1.51.1
Authors@R: c(person("Laurent", "Gatto", role=c("aut", "cre"),
                    email="laurent.gatto@uclouvain.be"),
             person("Sebastian", "Gibb", role="ctb",
                    email="mail@sebastiangibb.de"),
             person("Vlad", "Petyuk", role="ctb",
                    email="petyuk@gmail.com"),
             person('Thomas', 'Pedersen Lin', role='ctb',
                    email='thomasp85@gmail.com'))
Depends: R (>= 3.5), MSnbase (>= 2.35.2)
Imports: R.utils, biocViews, BiocManager
Suggests: QFeatures, AnnotationDbi, rpx (>= 2.0.3), DT, knitr,
        rmarkdown, BiocStyle, mzR, xcms, msdata, MALDIquant (>= 1.12),
        MALDIquantForeign, readBrukerFlexData, Rdisop, OrgMassSpecR,
        SummarizedExperiment, BRAIN, hpar, GO.db, org.Hs.eg.db, e1071,
        biomaRt, RColorBrewer, ggplot2, reshape2, xtable, lattice,
        mzID, pRoloc, pRolocdata, MSnID, msmsTests, msmsEDA, corrplot,
        beanplot, Heatplus, gplots, VennDiagram, protViz, genefilter,
        plotly, gridExtra, dplyr, lubridate, magick, cleaver
Description: This package contains code to illustrate the 'Using R and
    Bioconductor for proteomics data analysis' and
    'Visualisation of proteomics data using R and
    Bioconductor' manuscripts. The vignettes describe the
    code and data needed to reproduce the examples and
    figures described in the paper and functionality for
    proteomics visualisation. It also contain various
    function to discover R software for mass spectrometry and
    proteomics.
URL: http://lgatto.github.com/RforProteomics/
biocViews: ExperimentData, MassSpectrometryData, ReproducibleResearch
License: Artistic-2.0
VignetteBuilder: knitr
RoxygenNote: 7.1.1
git_url: https://git.bioconductor.org/packages/RforProteomics
git_branch: devel
git_last_commit: 4e43c34
git_last_commit_date: 2026-07-15
Repository: Bioconductor 3.24
Date/Publication: 2026-07-16
NeedsCompilation: no
Packaged: 2026-07-16 15:40:36 UTC; biocbuild
Author: Laurent Gatto [aut, cre],
  Sebastian Gibb [ctb],
  Vlad Petyuk [ctb],
  Thomas Pedersen Lin [ctb]
Maintainer: Laurent Gatto <laurent.gatto@uclouvain.be>
